@@ -45,7 +45,7 @@
 
 #if DIAGNOSTICS_INTERNAL_SWITCH_USE_ACE == 1
 
-#  include <ace/OS.h> // for pid_t and ACE_thread_t
+#  include <ace/Thread.h> // for pid_t and ACE_thread_t
 
 DIAGNOSTICS_NAMESPACE_BEGIN;
 typedef pid_t Pid_t;
