@@ -58,7 +58,7 @@
  * @brief Pretty printed function name
  */
 #ifndef DIAGNOSTICS_FUNC_NAME
-#ifndef WIN32
+#if defined(__GNUC__) 
 #  define DIAGNOSTICS_FUNC_NAME __PRETTY_FUNCTION__
 #else
 #  define DIAGNOSTICS_FUNC_NAME __FUNCSIG__ 
