@@ -160,7 +160,7 @@ public:
 private:
     mutable int m_class_invariance_called;
 
-    volatile bool m_throw; // this is actually a bug in gcc (PR39115), volatile should not be necessary
+    bool m_throw;
 };
 
 
