@@ -70,7 +70,7 @@ using ::diagnostics::unittest::internal::Current_Test_Logger;
 #define EMTPY(e) ""
 #define EMPTY(e) ""
 
-#define PRED_WHAT(WHAT) (e.what()==WHAT)
+#define PRED_WHAT(WHAT) (0 == ::std::strcmp(e.what(),WHAT))
 
 #define TEST_CASE(EXPLICIT_TE) \
 { \
@@ -208,7 +208,7 @@ using ::diagnostics::unittest::internal::Current_Test_Logger;
       TEST_ASSERT_RECORD1(LEVEL_AUDIT,TYPE_WRONG_EXCEPTION,50,"EXPECTED.NAME=\"int\" EXPECTED.PREDICATE=\"true\""); \
     ++current; \
     TEST_ASSERT_RECORD1(LEVEL_AUDIT,TYPE_WRONG_EXCEPTION,60,"EXPECTED.NAME=\"Test_Exception\" " \
-			"EXPECTED.PREDICATE=\"(e.what()==\"other\")\" NAME=\"Test_Exception\" WHAT=\"what\""); \
+			"EXPECTED.PREDICATE=\"(0 == ::std::strcmp(e.what(),\"other\"))\" NAME=\"Test_Exception\" WHAT=\"what\""); \
     ++current; \
  \
     TEST_CHECK(current->type()==TYPE_LOG_CLOSE); \
