@@ -83,7 +83,7 @@ DIAGNOSTICS_NAMESPACE_END;
  * diagnostics::unittest::Stream_Test_System_Main
  *
  */
-#define STREAM_TEST_SYSTEM_MAIN \
+#define STREAM_TEST_SYSTEM_MAIN_ALL \
 DIAGNOSTICS_NAMESPACE_BEGIN; \
 void set_initial_loggers(::std::vector<Logger *> & loggers) \
 { \
@@ -101,5 +101,14 @@ int main(int argc,char ** argv) \
     return result; \
 } void dummy_procedure_for_semicolon_do_not_call()
 
+#ifdef __MINGW32__
+#  define STREAM_TEST_SYSTEM_MAIN \
+int _CRT_glob = 0; \
+STREAM_TEST_SYSTEM_MAIN_ALL
+#else
+#  define STREAM_TEST_SYSTEM_MAIN \
+STREAM_TEST_SYSTEM_MAIN_ALL
+#endif
+
 #endif
 // vim:ts=4:sw=4
