@@ -73,17 +73,17 @@ void File_Test_Data_Source::load(::std::string const & file_name)
 {
     using namespace ::diagnostics::internal;
     
-    ::std::ifstream file(file_name.c_str());
+    ::std::ifstream file(file_name.c_str(), ::std::ios::in | ::std::ios::binary);
     if(!file.good()) throw Test_System_Exception("Could not open " + file_name);
 
     int const header_length=512;
     char header[header_length];
     for(int i=0;i<512;++i) header[i]='c';
     file.read(header,header_length);
-    if(!file.good()) throw Test_System_Exception("Error while reading " + file_name);
+    if(!file.good()) throw Test_System_Exception("Error while reading header of " + file_name);
 
     Data_t new_data;
-    if(!read(file,new_data)) throw Test_System_Exception("Error while reading " + file_name);
+    if(!read(file,new_data)) throw Test_System_Exception("Error while reading data from " + file_name);
 
     // nothing changed in this about this line -- no exceptions down here
     m_initialized=false;
