@@ -168,7 +168,7 @@ Stream_Test_System_Implementation(Level_t const build_level,
                  + level_to_string(static_cast<Level_t>(level)) + "' (numerically: " 
                  + to_string(level) + ") failed to one of PRO,DEB,AUD, or TES");
         }
-        else throw Test_System_Exception(::std::string("unkown command: '")+m_argv[1+cmd_offset]+"'");
+        else throw Test_System_Exception(::std::string("unknown command: '")+m_argv[1+cmd_offset]+"'");
     }
     }
 
