@@ -51,8 +51,8 @@ TEST_NAMESPACE_BEGIN;
     char const * const search_string("Test_Run_Result ");
     int const search_string_len(::std::strlen(search_string));
 
-    int last_pos(0);
-    int pos(in.find(search_string));
+    ::std::string::size_type last_pos(0);
+    ::std::string::size_type pos(in.find(search_string));
     for(;pos!= ::std::string::npos; pos=in.find(search_string,last_pos)){
 	pos+=search_string_len;
 	result.append("XX");
