@@ -2,8 +2,11 @@
  * Diagnostics - a unified framework for code annotation, logging,
  * program monitoring, and unit-testing.
  *
- * Copyright (C) 2002-2005 Christian Schallhart
+ * Copyright (C) 2009 Christian Schallhart <christian@schallhart.net>,
+ *                    Michael Tautschnig <tautschnig@forsyte.de>
+ *               2008 model.in.tum.de group, FORSYTE group
  *               2006-2007 model.in.tum.de group
+ *               2002-2005 Christian Schallhart
  *  
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,7 +30,7 @@
  * @brief [LEVEL: alpha] Implementation of @ref
  * diagnostics::internal::Diff_Generator
  *
- * $Id: diff_generator.cpp 834 2007-12-23 16:23:36Z tautschn $
+ * $Id: diff_generator.cpp 861 2009-04-18 20:14:51Z tautschnig $
  * 
  * @author Michael Tautschnig, Piotr Esden-Tempski 
  */
@@ -172,8 +175,8 @@ void Diff_Generator::p_do_diff()
 
     // LCSS matrix
     // this may overflow, do some checking ...
-    int const mva_b( ::log2( m_vtexta.size() ) );
-    int const mvb_b( ::log2( m_vtextb.size() ) );
+	int const mva_b( ::log( static_cast<double>(m_vtexta.size()) ) / ::log(2.0) );
+	int const mvb_b( ::log( static_cast<double>(m_vtextb.size()) ) / ::log(2.0) );
     if( mva_b + mvb_b + 1 > static_cast< int >( sizeof( int ) * 8 ) ) throw Diff_Exception( "Text too large for diff" );
     if( m_vtexta.size() > static_cast< ::std::vector<int>::size_type >( 
                 ::std::numeric_limits< int >::max() ) ) throw Diff_Exception( "Text too large for diff" );
